@@ -114,14 +114,18 @@ int main(int argc, char **argv) {
 		    schema = xmlSchemaParse(ctxt);
 		    xmlSchemaFreeParserCtxt(ctxt);
 		}
+#ifdef LIBXML_OUTPUT_ENABLED
 #ifdef LIBXML_DEBUG_ENABLED
 		if (debug)
 		    xmlSchemaDump(stdout, schema);
 #endif
+#endif /* LIBXML_OUTPUT_ENABLED */
+		if (schema == NULL)
+		    goto failed_schemas;
 	    } else {
 		xmlDocPtr doc;
 
-		doc = xmlParseFile(argv[i]);
+		doc = xmlReadFile(argv[i],NULL,0);
 
 		if (doc == NULL) {
 		    fprintf(stderr, "Could not parse %s\n", argv[i]);
@@ -164,6 +168,7 @@ int main(int argc, char **argv) {
 	printf("\t--memory : test the schemas in memory parsing\n");
 #endif
     }
+failed_schemas:
     xmlSchemaCleanupTypes();
     xmlCleanupParser();
     xmlMemoryDump();
@@ -173,7 +178,7 @@ int main(int argc, char **argv) {
 
 #else
 #include <stdio.h>
-int main(int argc, char **argv) {
+int main(int argc ATTRIBUTE_UNUSED, char **argv ATTRIBUTE_UNUSED) {
     printf("%s : Schemas support not compiled in\n", argv[0]);
     return(0);
 }
